"use strict";

var _toConsumableArray = require("babel-runtime/helpers/to-consumable-array")["default"];

var _extends = require("babel-runtime/helpers/extends")["default"];

var _defineProperty = require("babel-runtime/helpers/define-property")["default"];

var _Object$defineProperty = require("babel-runtime/core-js/object/define-property")["default"];

_Object$defineProperty(exports, "__esModule", {
    value: true
});

exports.to = to;
/**
 * Unwraps the iterator into a collection.
 *
 * @this {Iterable<iT>}
 * @param Type The constructor for the collection type.
 * @example Arrays
 *
 * ```javascript
 * [1,2,3].map(function () {
 *   return this * 2;
 * })::to(Array) // returns [2, 4, 6]
 * ```
 *
 * @example Objects
 *
 * ```javascript
 * [{id: "a"}, {id: "b"}].map(function () {
 *   return [this.id, this];
 * })::to(Object); // returns { a: { id: "a" }, b: { id: "b"} }
 * ```
 *
 * @example Other Collections
 *
 * ```javascript
 * [2.5, 3.5]::to(Uint16Array) // returns Uint16Array [2, 3]
 * ["foo", "bar", "foo"]::to(Set) // returns Set ["foo", "bar"]
 * [["x", "y"], ["z", "n"]]::to(Map) // returns Map { "x": "y", "z": "n" }
 * ```
*/

function to(Type) {
    if (Type === Array) {
        return [].concat(_toConsumableArray(this));
    } else if (Type === Object) {
        return [].concat(_toConsumableArray(this)).reduce(function (accumulation, entry) {
            return _extends({}, accumulation, _defineProperty({}, entry[0], entry[1]));
        }, {});
    } else {
        return new Type([].concat(_toConsumableArray(this)));
    }
}

;