"use strict";

var _regeneratorRuntime = require("babel-runtime/regenerator")["default"];

var _Object$defineProperty = require("babel-runtime/core-js/object/define-property")["default"];

var _getIterator = require("babel-runtime/core-js/get-iterator")["default"];

_Object$defineProperty(exports, "__esModule", {
    value: true
});

exports.union = union;
var marked0$0 = [union].map(_regeneratorRuntime.mark);
/**
 * Yields the sorted union iterator of two sorted iterators.
 *
 * @this {Iterable<T>}
 * @param comparator The sorting value function. Should return `0` when items are equal, a positive number when the item on the left is greater and a negative number when the item on the right is greater.
 * @ntime O(n+m)
 * @dspace O(2)
 * @example Basic Usage
 *
 * ```javascript
 * [2,3,4,7,8,9]::union([1,5,6,7], function (b) {
 *   return this - b;
 * }); // yields 1,2,3,4,5,6,7,8,9
 * ```
*/

function union(b, comparator) {
    var iteratorA, iteratorB, stepA, stepB, _context, comparison;

    return _regeneratorRuntime.wrap(function union$(context$1$0) {
        while (1) switch (context$1$0.prev = context$1$0.next) {
            case 0:
                iteratorA = _getIterator(this);
                iteratorB = _getIterator(b);
                stepA = iteratorA.next();
                stepB = iteratorB.next();

            case 4:
                if (!(!stepA.done && !stepB.done)) {
                    context$1$0.next = 24;
                    break;
                }

                comparison = (_context = stepA.value, comparator).call(_context, stepB.value);

                if (!(comparison < 0)) {
                    context$1$0.next = 12;
                    break;
                }

                context$1$0.next = 9;
                return stepA.value;

            case 9:
                stepA = iteratorA.next();
                context$1$0.next = 22;
                break;

            case 12:
                if (!(comparison > 0)) {
                    context$1$0.next = 18;
                    break;
                }

                context$1$0.next = 15;
                return stepB.value;

            case 15:
                stepB = iteratorB.next();
                context$1$0.next = 22;
                break;

            case 18:
                context$1$0.next = 20;
                return stepA.value;

            case 20:
                stepA = iteratorA.next();
                stepB = iteratorB.next();

            case 22:
                context$1$0.next = 4;
                break;

            case 24:
                if (stepA.done) {
                    context$1$0.next = 30;
                    break;
                }

                context$1$0.next = 27;
                return stepA.value;

            case 27:
                return context$1$0.delegateYield(iteratorA, "t0", 28);

            case 28:
                context$1$0.next = 34;
                break;

            case 30:
                if (stepB.done) {
                    context$1$0.next = 34;
                    break;
                }

                context$1$0.next = 33;
                return stepB.value;

            case 33:
                return context$1$0.delegateYield(iteratorB, "t1", 34);

            case 34:
            case "end":
                return context$1$0.stop();
        }
    }, marked0$0[0], this);
}

;